Title: [290917] branches/safari-613-branch
Revision
290917
Author
[email protected]
Date
2022-03-07 14:08:59 -0800 (Mon, 07 Mar 2022)

Log Message

Cherry-pick r289101. rdar://problem/87625596

    Two bopomofo tone marks are not moved to the correct place in vertical text with a particular bopomofo font
    https://bugs.webkit.org/show_bug.cgi?id=235257
    <rdar://problem/87625596>

    Reviewed by Darin Adler.

    .:

    Thank you so much to Bobby Tung and But Ko for reporting this bug and providing a test font for it!!!

    * metadata/contributors.json:

    Source/WebCore:

    Turns out one of our character data tables was missing some characters.

    I really dislike these kinds of fixes, because it's just perpetuating the fact that WebKit has big tables of characters
    in its source code. A long-term fix would be a systemic replacement of this entire table with either Unicode property
    lookup, or more ideally, removing the need for it in the first place. Unfortunately, at this point in the release cycle,
    this fix probably needs to be smaller and more targetted.

    Tests: fast/text/bopomofo-tone-marks-2.html
           fast/text/bopomofo-tone-marks.html

    * platform/graphics/FontCascade.cpp:
    (WebCore::FontCascade::isCJKIdeographOrSymbol):

    LayoutTests:

    This can't be a WPT test because we only have permission to add the test font to the WebKit repository.

    Thank you so much to Bobby Tung and But Ko for reporting this bug and providing a test font for it!!!

    * fast/text/bopomofo-tone-marks-2-expected-mismatch.html: Added.
    * fast/text/bopomofo-tone-marks-2.html: Added.
    * fast/text/bopomofo-tone-marks-expected-mismatch.html: Added.
    * fast/text/bopomofo-tone-marks.html: Added.
    * fast/text/resources/BopomofoGposSubset-Regular/BopomofoGposSubset-Regular.ttf: Added.
    * fast/text/resources/BopomofoGposSubset-Regular/LICENSE: Added.

    git-svn-id: https://svn.webkit.org/repository/webkit/trunk@289101 268f45cc-cd09-0410-ab3c-d52691b4dbfc

Modified Paths

Added Paths

Diff

Modified: branches/safari-613-branch/ChangeLog (290916 => 290917)


--- branches/safari-613-branch/ChangeLog	2022-03-07 22:08:54 UTC (rev 290916)
+++ branches/safari-613-branch/ChangeLog	2022-03-07 22:08:59 UTC (rev 290917)
@@ -1,3 +1,61 @@
+2022-03-07  Russell Epstein  <[email protected]>
+
+        Cherry-pick r289101. rdar://problem/87625596
+
+    Two bopomofo tone marks are not moved to the correct place in vertical text with a particular bopomofo font
+    https://bugs.webkit.org/show_bug.cgi?id=235257
+    <rdar://problem/87625596>
+    
+    Reviewed by Darin Adler.
+    
+    .:
+    
+    Thank you so much to Bobby Tung and But Ko for reporting this bug and providing a test font for it!!!
+    
+    * metadata/contributors.json:
+    
+    Source/WebCore:
+    
+    Turns out one of our character data tables was missing some characters.
+    
+    I really dislike these kinds of fixes, because it's just perpetuating the fact that WebKit has big tables of characters
+    in its source code. A long-term fix would be a systemic replacement of this entire table with either Unicode property
+    lookup, or more ideally, removing the need for it in the first place. Unfortunately, at this point in the release cycle,
+    this fix probably needs to be smaller and more targetted.
+    
+    Tests: fast/text/bopomofo-tone-marks-2.html
+           fast/text/bopomofo-tone-marks.html
+    
+    * platform/graphics/FontCascade.cpp:
+    (WebCore::FontCascade::isCJKIdeographOrSymbol):
+    
+    LayoutTests:
+    
+    This can't be a WPT test because we only have permission to add the test font to the WebKit repository.
+    
+    Thank you so much to Bobby Tung and But Ko for reporting this bug and providing a test font for it!!!
+    
+    * fast/text/bopomofo-tone-marks-2-expected-mismatch.html: Added.
+    * fast/text/bopomofo-tone-marks-2.html: Added.
+    * fast/text/bopomofo-tone-marks-expected-mismatch.html: Added.
+    * fast/text/bopomofo-tone-marks.html: Added.
+    * fast/text/resources/BopomofoGposSubset-Regular/BopomofoGposSubset-Regular.ttf: Added.
+    * fast/text/resources/BopomofoGposSubset-Regular/LICENSE: Added.
+    
+    git-svn-id: https://svn.webkit.org/repository/webkit/trunk@289101 268f45cc-cd09-0410-ab3c-d52691b4dbfc
+
+    2022-02-03  Myles C. Maxfield  <[email protected]>
+
+            Two bopomofo tone marks are not moved to the correct place in vertical text with a particular bopomofo font
+            https://bugs.webkit.org/show_bug.cgi?id=235257
+            <rdar://problem/87625596>
+
+            Reviewed by Darin Adler.
+
+            Thank you so much to Bobby Tung and But Ko for reporting this bug and providing a test font for it!!!
+
+            * metadata/contributors.json:
+
 2022-01-09  Sam Weinig  <[email protected]>
 
         Remove support for Direct2D

Modified: branches/safari-613-branch/LayoutTests/ChangeLog (290916 => 290917)


--- branches/safari-613-branch/LayoutTests/ChangeLog	2022-03-07 22:08:54 UTC (rev 290916)
+++ branches/safari-613-branch/LayoutTests/ChangeLog	2022-03-07 22:08:59 UTC (rev 290917)
@@ -1,5 +1,70 @@
 2022-03-07  Russell Epstein  <[email protected]>
 
+        Cherry-pick r289101. rdar://problem/87625596
+
+    Two bopomofo tone marks are not moved to the correct place in vertical text with a particular bopomofo font
+    https://bugs.webkit.org/show_bug.cgi?id=235257
+    <rdar://problem/87625596>
+    
+    Reviewed by Darin Adler.
+    
+    .:
+    
+    Thank you so much to Bobby Tung and But Ko for reporting this bug and providing a test font for it!!!
+    
+    * metadata/contributors.json:
+    
+    Source/WebCore:
+    
+    Turns out one of our character data tables was missing some characters.
+    
+    I really dislike these kinds of fixes, because it's just perpetuating the fact that WebKit has big tables of characters
+    in its source code. A long-term fix would be a systemic replacement of this entire table with either Unicode property
+    lookup, or more ideally, removing the need for it in the first place. Unfortunately, at this point in the release cycle,
+    this fix probably needs to be smaller and more targetted.
+    
+    Tests: fast/text/bopomofo-tone-marks-2.html
+           fast/text/bopomofo-tone-marks.html
+    
+    * platform/graphics/FontCascade.cpp:
+    (WebCore::FontCascade::isCJKIdeographOrSymbol):
+    
+    LayoutTests:
+    
+    This can't be a WPT test because we only have permission to add the test font to the WebKit repository.
+    
+    Thank you so much to Bobby Tung and But Ko for reporting this bug and providing a test font for it!!!
+    
+    * fast/text/bopomofo-tone-marks-2-expected-mismatch.html: Added.
+    * fast/text/bopomofo-tone-marks-2.html: Added.
+    * fast/text/bopomofo-tone-marks-expected-mismatch.html: Added.
+    * fast/text/bopomofo-tone-marks.html: Added.
+    * fast/text/resources/BopomofoGposSubset-Regular/BopomofoGposSubset-Regular.ttf: Added.
+    * fast/text/resources/BopomofoGposSubset-Regular/LICENSE: Added.
+    
+    git-svn-id: https://svn.webkit.org/repository/webkit/trunk@289101 268f45cc-cd09-0410-ab3c-d52691b4dbfc
+
+    2022-02-03  Myles C. Maxfield  <[email protected]>
+
+            Two bopomofo tone marks are not moved to the correct place in vertical text with a particular bopomofo font
+            https://bugs.webkit.org/show_bug.cgi?id=235257
+            <rdar://problem/87625596>
+
+            Reviewed by Darin Adler.
+
+            This can't be a WPT test because we only have permission to add the test font to the WebKit repository.
+
+            Thank you so much to Bobby Tung and But Ko for reporting this bug and providing a test font for it!!!
+
+            * fast/text/bopomofo-tone-marks-2-expected-mismatch.html: Added.
+            * fast/text/bopomofo-tone-marks-2.html: Added.
+            * fast/text/bopomofo-tone-marks-expected-mismatch.html: Added.
+            * fast/text/bopomofo-tone-marks.html: Added.
+            * fast/text/resources/BopomofoGposSubset-Regular/BopomofoGposSubset-Regular.ttf: Added.
+            * fast/text/resources/BopomofoGposSubset-Regular/LICENSE: Added.
+
+2022-03-07  Russell Epstein  <[email protected]>
+
         Cherry-pick r287898. rdar://problem/86035420
 
     Rewrite touch and drag tests to be more robust.

Added: branches/safari-613-branch/LayoutTests/fast/text/bopomofo-tone-marks-2-expected-mismatch.html (0 => 290917)


--- branches/safari-613-branch/LayoutTests/fast/text/bopomofo-tone-marks-2-expected-mismatch.html	                        (rev 0)
+++ branches/safari-613-branch/LayoutTests/fast/text/bopomofo-tone-marks-2-expected-mismatch.html	2022-03-07 22:08:59 UTC (rev 290917)
@@ -0,0 +1,17 @@
+<!DOCTYPE html>
+<html>
+<head>
+<meta charset="utf-8">
+<style>
+@font-face {
+    font-family: "BopomofoGposSubset";
+    src: url("resources/BopomofoGposSubset-Regular/BopomofoGposSubset-Regular.ttf") format("truetype");
+}
+</style>
+</head>
+<body>
+<div style="overflow: hidden;">
+<div style="writing-mode: vertical-rl; font: 48px 'BopomofoGposSubset';">ㄏㄜ</div>
+</div>
+</body>
+</html>

Added: branches/safari-613-branch/LayoutTests/fast/text/bopomofo-tone-marks-2.html (0 => 290917)


--- branches/safari-613-branch/LayoutTests/fast/text/bopomofo-tone-marks-2.html	                        (rev 0)
+++ branches/safari-613-branch/LayoutTests/fast/text/bopomofo-tone-marks-2.html	2022-03-07 22:08:59 UTC (rev 290917)
@@ -0,0 +1,17 @@
+<!DOCTYPE html>
+<html>
+<head>
+<meta charset="utf-8">
+<style>
+@font-face {
+    font-family: "BopomofoGposSubset";
+    src: url("resources/BopomofoGposSubset-Regular/BopomofoGposSubset-Regular.ttf") format("truetype");
+}
+</style>
+</head>
+<body>
+<div style="overflow: hidden;">
+<div style="writing-mode: vertical-rl; font: 48px 'BopomofoGposSubset';">ㄏㄜ˫</div>
+</div>
+</body>
+</html>

Added: branches/safari-613-branch/LayoutTests/fast/text/bopomofo-tone-marks-expected-mismatch.html (0 => 290917)


--- branches/safari-613-branch/LayoutTests/fast/text/bopomofo-tone-marks-expected-mismatch.html	                        (rev 0)
+++ branches/safari-613-branch/LayoutTests/fast/text/bopomofo-tone-marks-expected-mismatch.html	2022-03-07 22:08:59 UTC (rev 290917)
@@ -0,0 +1,17 @@
+<!DOCTYPE html>
+<html>
+<head>
+<meta charset="utf-8">
+<style>
+@font-face {
+    font-family: "BopomofoGposSubset";
+    src: url("resources/BopomofoGposSubset-Regular/BopomofoGposSubset-Regular.ttf") format("truetype");
+}
+</style>
+</head>
+<body>
+<div style="overflow: hidden;">
+<div style="writing-mode: vertical-rl; font: 48px 'BopomofoGposSubset';">ㄊㄞ</div>
+</div>
+</body>
+</html>

Added: branches/safari-613-branch/LayoutTests/fast/text/bopomofo-tone-marks.html (0 => 290917)


--- branches/safari-613-branch/LayoutTests/fast/text/bopomofo-tone-marks.html	                        (rev 0)
+++ branches/safari-613-branch/LayoutTests/fast/text/bopomofo-tone-marks.html	2022-03-07 22:08:59 UTC (rev 290917)
@@ -0,0 +1,17 @@
+<!DOCTYPE html>
+<html>
+<head>
+<meta charset="utf-8">
+<style>
+@font-face {
+    font-family: "BopomofoGposSubset";
+    src: url("resources/BopomofoGposSubset-Regular/BopomofoGposSubset-Regular.ttf") format("truetype");
+}
+</style>
+</head>
+<body>
+<div style="overflow: hidden;">
+<div style="writing-mode: vertical-rl; font: 48px 'BopomofoGposSubset';">ㄊㄞ˪</div>
+</div>
+</body>
+</html>

Added: branches/safari-613-branch/LayoutTests/fast/text/resources/BopomofoGposSubset-Regular/BopomofoGposSubset-Regular.ttf (0 => 290917)


--- branches/safari-613-branch/LayoutTests/fast/text/resources/BopomofoGposSubset-Regular/BopomofoGposSubset-Regular.ttf	                        (rev 0)
+++ branches/safari-613-branch/LayoutTests/fast/text/resources/BopomofoGposSubset-Regular/BopomofoGposSubset-Regular.ttf	2022-03-07 22:08:59 UTC (rev 290917)
@@ -0,0 +1,73 @@
+����������\x80����`DSIG����������x������GSUB\xFC"\xC3����d������\xC0OS/2mj\x99\x94����0������`cmapcsfe����\x90������dglyf\xEF\xE0\xB8"������\xEC����	|head .\xA5\xD0����
+\xA4������6hhea2l����������$hmtx&\x87����
+\xDC������.locaD����
+\x88������maxp��\x83��\xB7����
+h������ name\xE9\xE5
+\x9E����\xF4����\xDCpostA6\x96\xB8����\xD0������\x92vhea��\x9A\xDA����T������$vmtx1\xFC\x84����$������.��
+��]\xFF\x88\x9Ap����������$��.��4��@��D��H����E!!5#735#375#75#353#5#75##7535#3#75#5#75#535#3#3#3#\x9A\xFE\xC3=MfF \xA6FF\xA6\xA6\xA6d"!d!\xA6!\x85dB\xA6BB\xA6Bd\xA6BB\xA5AB!dd!!x\xE8\xFC]!/!!/!\x88qq\xADq8/Pq\x87dB"9F!!%!\x82"Fh\x82!%!!%!\xFD\xDF/$����/��\xA2E��v����@&#"327676?/&77"&'&&'#"&'&766767&'&54?67667476676763q	*Tg/.=%
+./+	*d/;8:;
+
+K\x80\xC72+ @CVR,U&~N'+	\x929RW
+@qt"  
+*A"+*0+#,h\xC0+
+$\x8F(@	 
+	01		����������\x84\xFF\xE8k��\x97����@'&#"'&#"67767672735476676654&#&'"'4767667667#&'&54766763232677676766774'#"&'&546377%676632k
+	*Iv-]5TJB20Q0&!\x82E&Z"A\x84b22
+	\x93]
+++:\xA2  \xEE+D;3
+1\x80$$!H.	O\xD7]		4`;5ph3'\x83t0
+++=	
+$A*?
+����z\xFF\xCFv;��\��h����@#"&&54663276676&'"&'&547677667676363236767767277��32654&#"+'$	++/M24%1S11S1Ac+%B+P(p'( \x95,
+&+#(>?<j\x9F$\xFEYC//BC./CW.'	&*;t\x91'+1S11S1R>+E\xABC	/)I5+`$
++\xFD\xFDBB0.BB.��������\xFF\xD4\x9F\xEA��x����@33636677632#"&'&'&'&&''#"'&&'&54676767'&&'&54637276776766766754766'&#"Y++%$2:I+2*9\x8A ?+=2V# 
+@%+<#xf5;%		!%."E`U? 2#i#dRP (\x95.1%
+	
+.Oc E>A	!
+++M5 EW	������\x80\xFB\x9E��0����@77632#"'&547654&'&5432](Z\x8BB  !\xCCG'	\x94".>!	/I$+	%(\x88H\x85 	����K��\x9A��%����d&'&''&'&327667632#7	!
+O\xCF)
+&6\xB0}K5*aots!
+JY
+'\x8B4'����\xFE\xDF\xA0��\xCB\xBE��/����B77632#"'&547654&'&5432\xD3(Z\x8BB  !\xCCG'	\xB4".>!#I/$+	%(\x88H\x85 	��������\xFE\xDFk��\xD0\xBA��"����B&'&''&'&32%632#\xF9	!
+]
+&J\xF6#k5*aots!
+JY 
+	;\x8B4'����\x98\xF3\xB6��0����@77632#"'&547654&'&5432U(Z\x8BB  !\xCCG'	\xAC".>!	/I$+	%(\x88H\x85 	��c\xF8\xB2��"����@&'&''&'&32%632#/	!
+]
+&J\xF6#c5*aots!
+JY 
+	;\x8B4'����������\x98��
+����������������������d������������������b��b\xEE\x8A:\x82\xBE>\x86\xBE������������\x99m-\x8D_<\xF5��\xE8��������\xDE \xCE��������\xDE #G\xFE\xDF\xFF\x88\xF8\xB6��������������������\xF4��]X����\xE8��/\xE8��\x84\xE8��z\xE8��\xE8\xE8,\xFE\xDF,\xFE\xDF\xE8����������p\xFF\x88\xE8\xE8\xFE\xDF\xFD\xF0\xF8����������������������������������(\x90����\x8AX������K\x8AX����^��2,����	������������������#����������������������UKWN��\xC0�� 1\xA4p\xFF\x88\xE8p��x��������������X\xBC������ ����������������������������������P���������������� ��\xA0\xEB1
+11\xA01\xA4\xFF\xFF������ ��\xA0\xEA1
+11\xA01\xA4\xFF\xFF\xFF\xE1\xFFa\xFD\xCE\xF8\xCE\xE5\xCEd\xCEa������������������������������������������\xBA����������������������������������������������������������������+��3����������������@����	����$��Z����	������~����	����J��\x8C����	����4��\xD6����	����
+����	����4$����	��+\x96X����	����4\xEE����	����$��Z����	������~BopomofoGposSubsetRegularBopomofoGposSubset RegularVersion 1.100BopomofoGposSubset-Regular��B��o��p��o��m��o��f��o��G��p��o��s��S��u��b��s��e��t��R��e��g��u��l��a��r��1��.��1��0��0��;��U��K��W��N��;��B��o��p��o��m��o��f��o��G��p��o��s��S��u��b��s��e��t��-��R��e��g��u��l��a��r��B��o��p��o��m��o��f��o��G��p��o��s��S��u��b��s��e��t�� ��R��e��g��u��l��a��r��V��e��r��s��i��o��n�� ��1��.��1��0��0��B��o��p��o��m��o��f��o��G��p��o��s��S��u��b��s��e��t��-��R��e��g��u��l��a��r��T��h��i��s�� ��F��o��n��t�� ��S��o��f��t��w��a��r��e�� ��i��s�� ��l��i��c��e��n��s��e��d�� ��u��n��d��e��r�� ��t��h��e�� ��S��I��L�� ��O��p��e��n�� ��F��o��n��t�� ��L��i��c��e��n��s��e��,�� ��V��e��r��s��i��o��n�� ��1��.��1��.�� ��T��h��i��s�� ��F��o��n��t�� ��S��o��f��t��w��a��r��e�� ��i��s�� ��d��i��s��t��r��i��b��u��t��e��d�� ��o��n�� ��a��n�� ��"��A��S�� ��I��S��"�� ��B��A��S��I��S��,�� ��W��I��T��H��O��U��T�� ��W��A��R
 ��R��A��N��T��I��E��S�� ��O��R�� ��C��O��N��D��I��T��I��O��N��S�� ��O��F�� ��A��N��Y�� ��K��I��N��D��,�� ��e��i��t��h��e��r�� ��e��x��p��r��e��s��s�� ��o��r�� ��i��m��p��l��i��e��d��.�� ��S��e��e�� ��t��h��e�� ��S��I��L�� ��O��p��e��n�� ��F��o��n��t�� ��L��i��c��e��n��s��e�� ��f��o��r�� ��t��h��e�� ��s��p��e��c��i��f��i��c�� ��l��a��n��g��u��a��g��e��,�� ��p��e��r��m��i��s��s��i��o��n��s�� ��a��n��d�� ��l��i��m��i��t��a��t��i��o��n
 ��s�� ��g��o��v��e��r��n��i��n��g�� ��y��o��u��r�� ��u��s��e�� ��o��f�� ��t��h��i��s�� ��F��o��n��t�� ��S��o��f��t��w��a��r��e��.��h��t��t��p��:��/��/��s��c��r��i��p��t��s��.��s��i��l��.��o��r��g��/��O��F��L��������������\xFF\x9C��2������������������������������������������������	
+uni310Auni311Euni31A0uni31A4uni02EAuni02EB	uni02EA.h	uni02EB.h	uni02EA.v	uni02EB.v������������
+��N��\x96��DFLT��hani��$latn��4����������\xFF\xFF��������������������\xFF\xFF������������������\xFF\xFF����������	aalt��8aalt��8aalt��8salt��<salt��<salt��<vert��Bvert��Bvert��B������������������������������������������������������������������������\xE8����\xE8p\xE8��+\xE8��d\xE8��5\xE8��\x86������\xD2������\xD6����\xFD\xB2����\xFD\xB6��\xFA\xBA\xFA\xBE��������\xF4\xFE\xE8\xE8\xFA\xBA\xFC\xDB��������������������������������������������������
\ No newline at end of file

Added: branches/safari-613-branch/LayoutTests/fast/text/resources/BopomofoGposSubset-Regular/LICENSE (0 => 290917)


--- branches/safari-613-branch/LayoutTests/fast/text/resources/BopomofoGposSubset-Regular/LICENSE	                        (rev 0)
+++ branches/safari-613-branch/LayoutTests/fast/text/resources/BopomofoGposSubset-Regular/LICENSE	2022-03-07 22:08:59 UTC (rev 290917)
@@ -0,0 +1 @@
+This Font Software is licensed under the SIL Open Font License, Version 1.1.

Modified: branches/safari-613-branch/Source/WebCore/ChangeLog (290916 => 290917)


--- branches/safari-613-branch/Source/WebCore/ChangeLog	2022-03-07 22:08:54 UTC (rev 290916)
+++ branches/safari-613-branch/Source/WebCore/ChangeLog	2022-03-07 22:08:59 UTC (rev 290917)
@@ -1,5 +1,72 @@
 2022-03-07  Russell Epstein  <[email protected]>
 
+        Cherry-pick r289101. rdar://problem/87625596
+
+    Two bopomofo tone marks are not moved to the correct place in vertical text with a particular bopomofo font
+    https://bugs.webkit.org/show_bug.cgi?id=235257
+    <rdar://problem/87625596>
+    
+    Reviewed by Darin Adler.
+    
+    .:
+    
+    Thank you so much to Bobby Tung and But Ko for reporting this bug and providing a test font for it!!!
+    
+    * metadata/contributors.json:
+    
+    Source/WebCore:
+    
+    Turns out one of our character data tables was missing some characters.
+    
+    I really dislike these kinds of fixes, because it's just perpetuating the fact that WebKit has big tables of characters
+    in its source code. A long-term fix would be a systemic replacement of this entire table with either Unicode property
+    lookup, or more ideally, removing the need for it in the first place. Unfortunately, at this point in the release cycle,
+    this fix probably needs to be smaller and more targetted.
+    
+    Tests: fast/text/bopomofo-tone-marks-2.html
+           fast/text/bopomofo-tone-marks.html
+    
+    * platform/graphics/FontCascade.cpp:
+    (WebCore::FontCascade::isCJKIdeographOrSymbol):
+    
+    LayoutTests:
+    
+    This can't be a WPT test because we only have permission to add the test font to the WebKit repository.
+    
+    Thank you so much to Bobby Tung and But Ko for reporting this bug and providing a test font for it!!!
+    
+    * fast/text/bopomofo-tone-marks-2-expected-mismatch.html: Added.
+    * fast/text/bopomofo-tone-marks-2.html: Added.
+    * fast/text/bopomofo-tone-marks-expected-mismatch.html: Added.
+    * fast/text/bopomofo-tone-marks.html: Added.
+    * fast/text/resources/BopomofoGposSubset-Regular/BopomofoGposSubset-Regular.ttf: Added.
+    * fast/text/resources/BopomofoGposSubset-Regular/LICENSE: Added.
+    
+    git-svn-id: https://svn.webkit.org/repository/webkit/trunk@289101 268f45cc-cd09-0410-ab3c-d52691b4dbfc
+
+    2022-02-03  Myles C. Maxfield  <[email protected]>
+
+            Two bopomofo tone marks are not moved to the correct place in vertical text with a particular bopomofo font
+            https://bugs.webkit.org/show_bug.cgi?id=235257
+            <rdar://problem/87625596>
+
+            Reviewed by Darin Adler.
+
+            Turns out one of our character data tables was missing some characters.
+
+            I really dislike these kinds of fixes, because it's just perpetuating the fact that WebKit has big tables of characters
+            in its source code. A long-term fix would be a systemic replacement of this entire table with either Unicode property
+            lookup, or more ideally, removing the need for it in the first place. Unfortunately, at this point in the release cycle,
+            this fix probably needs to be smaller and more targetted.
+
+            Tests: fast/text/bopomofo-tone-marks-2.html
+                   fast/text/bopomofo-tone-marks.html
+
+            * platform/graphics/FontCascade.cpp:
+            (WebCore::FontCascade::isCJKIdeographOrSymbol):
+
+2022-03-07  Russell Epstein  <[email protected]>
+
         Cherry-pick r288450. rdar://problem/74932445
 
     Remove customElements when transitioning documents

Modified: branches/safari-613-branch/Source/WebCore/platform/graphics/FontCascade.cpp (290916 => 290917)


--- branches/safari-613-branch/metadata/contributors.json	2022-03-07 22:08:54 UTC (rev 290916)
+++ branches/safari-613-branch/metadata/contributors.json	2022-03-07 22:08:59 UTC (rev 290917)
@@ -1117,6 +1117,13 @@
    },
    {
       "emails" : [
+         "[email protected]"
+      ],
+      "github" : "bobbytung",
+      "name" : "Bobby Tung"
+   },
+   {
+      "emails" : [
          "[email protected]"
       ],
       "expertise" : "Networking, Storage, WebCore icon database, Back/forward cache, History",
@@ -1201,6 +1208,13 @@
    },
    {
       "emails" : [
+         "[email protected]"
+      ],
+      "github" : "ButTaiwan",
+      "name" : "But Ko"
+   },
+   {
+      "emails" : [
          "[email protected]",
          "[email protected]"
       ],
_______________________________________________
webkit-changes mailing list
[email protected]
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to
--- branches/safari-613-branch/Source/WebCore/platform/graphics/FontCascade.cpp	2022-03-07 22:08:54 UTC (rev 290916)
+++ branches/safari-613-branch/Source/WebCore/platform/graphics/FontCascade.cpp	2022-03-07 22:08:59 UTC (rev 290917)
@@ -812,9 +812,11 @@
 {
     // 0x2C7 Caron, Mandarin Chinese 3rd Tone
     // 0x2CA Modifier Letter Acute Accent, Mandarin Chinese 2nd Tone
-    // 0x2CB Modifier Letter Grave Access, Mandarin Chinese 4th Tone 
-    // 0x2D9 Dot Above, Mandarin Chinese 5th Tone 
-    if ((c == 0x2C7) || (c == 0x2CA) || (c == 0x2CB) || (c == 0x2D9))
+    // 0x2CB Modifier Letter Grave Access, Mandarin Chinese 4th Tone
+    // 0x2D9 Dot Above, Mandarin Chinese 5th Tone
+    // 0x2EA Modifier Letter Yin Departing Tone Mark
+    // 0x2EB Modifier Letter Yang Departing Tone Mark
+    if ((c == 0x2C7) || (c == 0x2CA) || (c == 0x2CB) || (c == 0x2D9) || (c == 0x2EA) || (c == 0x2EB))
         return true;
 
     if ((c == 0x2020) || (c == 0x2021) || (c == 0x2030) || (c == 0x203B) || (c == 0x203C)

Modified: branches/safari-613-branch/metadata/contributors.json (290916 => 290917)

